@@ -1,8 +1,7 @@
-from datetime import datetime, timezone
 import pickle
 
 from drkns.configunit.ConfigUnit import ConfigUnit
-from drkns.configunit.ConfigUnit import StepExecutionStatus
+from drkns.stepexecutionstatus.StepExecutionStatus import StepExecutionStatus
 from drkns.context.Context import context
 from drkns.context.get_unit_step_path import get_unit_step_path
 
